@@ -13,7 +13,7 @@
 ##############################################################################
 """Interfaces to do with traversing.
 
-$Id: interfaces.py 95965 2009-02-02 12:25:12Z nadako $
+$Id: interfaces.py 100317 2009-05-23 22:05:12Z shane $
 """
 
 from zope.interface import Interface
@@ -139,3 +139,7 @@ class ITraversalAPI(Interface):
 class IPathAdapter(Interface):
     """Marker interface for adapters to be used in paths
     """
+
+class IEtcNamespace(Interface):
+    """Marker for utility registrations in the ++etc++ namespace
+    """
